import { Component, Input } from '@angular/core';
import { Router } from '@angular/router';
import { FormulaireDefinition } from 'app/formulaire/definition/form-definition';
import { FormulaireService } from 'app/services/formulaire.service';
import { fv } from 'app/util';
import { formattedValue } from 'jalhyd';

/**
 * liste déroulante de boutons de génération de formulaire "section paramétrée"
 */

@Component({
  selector: 'select-section-details',
  templateUrl: './select-section-details.component.html',
  styleUrls: ['./select-section-details.component.scss']
})
export class SelectSectionDetailsComponent {
  private _points: any[];

  /**
   * points auxquels on peut créer un formulaire "section paramétrée"
   */
  @Input()
  public set points(ps: any[]) {
    this._points = ps;
  }

  public get points(): any[] {
    return this._points;
  }

  constructor(
    private formulaireService: FormulaireService,
    private router: Router
  ) { }

  public pointLabel(p: any): string {
    return "x : " + formattedValue(p.x, 1) + " y : " + fv(p.z);
  }

  /**
   * Génère une SectionParametree à partir du module en cours
   */
  public async generateCrSp(p: any) {
    const f: FormulaireDefinition = await this.formulaireService.generateParametricSectionForm(p.y);

    // calculate form
    f.doCompute();

    // go to new form
    this.router.navigate(["/calculator", f.uid]);
  }

  public get uitextPlaceholder() {
    return "Générer une section paramétrée pour...";
  }
}
